@@ -1,5 +1,5 @@
-GOOF----LE-8-2.0_
-      ] , 4  h@      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
+GOOF----BE-8-2.0  
+_    ] , 4  h  @    ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
 g  api	
  	 	
 g  primitive-load-path	f  klondike	g  deal-one	g  
@@ -14,18 +14,18 @@ deal-cards	$		
 		 	%g  deal-cards-face-up	&																	
 						
 	 	'g  give-status-message	(g  new-game	)g  get-options	*g  
-apply-options	+g  set-lambda!C 5   h     ] 4	 >  "  G  4
-i>  "  G  RRR	RR !"#$%&'     h    ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  $  4	
+apply-options	+g  set-lambda!C 5   h     ] 4	 >  "  G  4
+i>  "  G  RRR	RR !"#$%&'     h    ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  $  4	
 	>  "  G  "  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4
->   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>   "  G  		 C          g  filenamef  
+>   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>   "  G  		 C          g  filenamef  
 aunt-mary.scm
 	
 							#	!		3	"		C	%		I	%		N	%		\	'		]	(		`	(	#	f	(	/	k	(		x	)		{	)		}	)	 	)	 	,	 	,	 	,	 	,	 	-	 	-	 	-	 	-	 	.	 	.	 	.	 	.	 	/	 	/	 	/	 	/	 	0	 	2	 	2	 	2	 	2	 	3	 	3		3		3		4		4		4		4	&	5	)	5	-	5	2	5	;	6	>	6	B	6	G	6	P	7	S	7	W	7	\	7	e	:	k	;	p	:	y	@		A		@		H		J	 C	
-  g  nameg  new-game C(R    h   W   ] C    O       g  filenamef  
+  g  nameg  new-game C(R    h      W] C       O    g  filenamef  
 aunt-mary.scm
 	M
  		
-  g  nameg  get-options C)R    h   o   ]C    g       g  options
+  g  nameg  get-options C)R    h      o]C       g    g  options
 		  g  filenamef  
 aunt-mary.scm
 	P
