@@ -1,4 +1,4 @@
-GOOF----BE-4-2.0  T    ] K 4   h  T    ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
+GOOF----LE-8-2.0T      ] K 4   hT      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
 g  api	
  	 	
 				 	g  
@@ -10,85 +10,85 @@ deal-cards	0g  button-double-clicked	1g  find-possible-move	2g  game-won
  	8g  begin-exclusive	9g  _	:f  Six Foundations	;f  Five Foundations	<f  Four Foundations	=g  
 end-exclusive	>g  get-options	?g  list-ref	@g  
 apply-options	Ag  	hint-move	Bf  Play a card to foundation.	Cf  	No moves.	Dg  get-hint	Eg  do-deal-next-cards	Fg  timeout	Gg  button-clicked	Hg  set-features	Ig  droppable-feature	Jg  
-set-lambdaC 5       h    ] 4	 >  "  G  
-R	RR  h   (   ]  (  "  $  C6         g  lst
+set-lambdaC 5       h    ] 4	 >  "  G  
+R	RR  h(      ]  (  "  $  C6         g  lst
 		& g  lcdr		& g  lcar			&  g  filenamef  eliminator.scm
 	
-						%													&		 			&  g  nameg  any CR  h   (   ]  (  "  $  C6        g  lst
+						%													&		 			&  g  nameg  any CR  h(      ]  (  "  $  C6        g  lst
 		' g  lcdr		' g  lcar			'  g  filenamef  eliminator.scm
 	
 		 			 	%		 			!			!			!	%		!		'	#	 
-		'  g  nameg  all CR       h      Y] C   Q    g  n
+		'  g  nameg  all CR       h   Y   ] CQ       g  n
 		  g  filenamef  eliminator.scm
-	?			?	& 		   C !"#        h    5] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  	$  4>  "  G  "   	$  4>  "  G  "   45 4	>   "  G  	$  4
+	?			?	& 		   C !"#        h  5  ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  	$  4>  "  G  "   	$  4>  "  G  "   45 4	>   "  G  	$  4
 >   "  G  "   4>  "  G  4>  "  G  4>  "  G  4>  "  G  4
 4	55 444	
-5?>  "  G  4>   "  G  	 C      -    g  filenamef  eliminator.scm
+5?>  "  G  4>   "  G  	 C    -      g  filenamef  eliminator.scm
 	(
 		)			*		#	+		3	,		C	/		F	/		K	/		T	0		W	0		\	0		e	1		h	1		m	1		v	2		y	2		~	2	 	3	 	3	 	3	 	3	. 	3	 	4	 	4	 	4	 	4	- 	4	 	5	 	5	 	7	 	8	 	8	 	8	 	;	 	;		;		<		<		<		=	"	=	)	=	2	>	5	>	<	>	E	?	J	?	7R	?	T	?	U	B	Z	B	+]	B	9g	B	+l	B	u	J		L	 9	
-  g  nameg  new-game C$R%&      h       ]4 5$  
+  g  nameg  new-game C$R%&      h       ]4 5$  
 45CC            g  slot-id
 		 g  	card-list		  g  filenamef  eliminator.scm
 	O
 		P	
-		P			P	)		P	& 			  g  nameg  button-pressed C'R()*+ h   @   ]4 5$  )45$  "  4>  "  G  6C           g  
+		P			P	)		P	& 			  g  nameg  button-pressed C'R()*+ h@      ]4 5$  )45$  "  4>  "  G  6C           g  
 start-slot
 		< g  	card-list		< g  end-slot			<  g  filenamef  eliminator.scm
 	R
-		S			S			U	!		U		!	U	9	8	V	,	:	V	 			<	  g  nameg  button-released C,R-.)(/*  h   p   ]M$  C4L 5$  "  4 5$  "  4L L  5$  -4L   >  "  G  4>  "  G  NCC            g  fid
+		S			S			U	!		U		!	U	9	8	V	,	:	V	 			<	  g  nameg  button-released C,R-.)(/*  hp      ]M$  C4L 5$  "  4 5$  "  4L L  5$  -4L   >  "  G  4>  "  G  NCC            g  fid
 		k  g  filenamef  eliminator.scm
-	]			^			`	-		_	$		a	-	%	_	$	+	b	(	4	b	8	8	b	(	<	_	 	=	d	(	F	d	8	K	d	(	T	e	(	g	f	( 		k   C        h   0   ]4 5H4 O >  "  G  JC         g  tid
+	]			^			`	-		_	$		a	-	%	_	$	+	b	(	4	b	8	8	b	(	<	_	 	=	d	(	F	d	8	K	d	(	T	e	(	g	f	( 		k   C        h0      ]4 5H4 O >  "  G  JC         g  tid
 		. g  card	
 	. g  mv		
 	.  g  filenamef  eliminator.scm
 	[
 		\		
-	\			]	 		.  g  nameg  button-double-clicked C0R!)(-    h   P   ]4L5$  CM &  34L4L5  5$  4 5$  "  	L  N CCC            g  fid
+	\			]	 		.  g  nameg  button-double-clicked C0R!)(-    hP      ]4L5$  CM &  34L4L5  5$  4 5$  "  	L  N CCC            g  fid
 		K  g  filenamef  eliminator.scm
 	x			y	*	
 	y	 		z	,		z	B	%	z	<	)	z	,	-	z	(	.	{	@	8	{	7	C	{	]	E	{	S 
-		K   C        h      []L  O 6          S    g  tid
+		K   C        h   [   ]L  O 6       S       g  tid
 		  g  filenamef  eliminator.scm
-	w	3		x	 		   C        h   0   ]H 444 O 5?5J $  J CC            g  fnd
+	w	3		x	 		   C        h0      ]H 444 O 5?5J $  J CC            g  fnd
 		+ g  tmp		+  g  filenamef  eliminator.scm
 	u
 		v			w				w	 		w	.		w	 		w			w		% 	 
 		+
-  g  nameg  find-possible-move C1R2)1   h   0   ]45 $  C4455  $   C45 C          g  t
+  g  nameg  find-possible-move C1R2)1   h0      ]45 $  C4455  $   C45 C          g  t
 		-  g  filenamef  eliminator.scm
  
 	 		 		 		 		 		 		' 		, 	 
 		-
-  g  nameg  game-continuable C3R)   h      h] 456    `    g  filenamef  eliminator.scm
+  g  nameg  game-continuable C3R)   h   h   ] 456 `       g  filenamef  eliminator.scm
  
 	 	
 	 	 		
-  g  nameg  game-won C2R%-)4567 	h     ]#45$  }4545$  C45$  U4545$  C$  C $  C CCC        g  
+  g  nameg  game-won C2R%-)4567 	h     ]#45$  }4545$  C45$  U4545$  C$  C $  C CCC        g  
 start-slot
 	  g  	card-list	  g  end-slot		  g  top-card		  g  t		  g  top		D  g  card		D  g  t		N  g  t		_  g  t		t   
 g  filenamef  eliminator.scm
  
 	 		 		 	 	 		 		 		+ 	%	5 	 	6 	3	= 	O	B 	Z	D 	O	D 	(	M 	@	N 	8	N 	0	^ 	@	_ 	8	_ 	0	q 	D	s 	T	t 	<	t 	8  	H  	X  	@ 	 	  g  nameg  
-droppable? C(R89:;<=        h   8   ] 45	 45	 45	  C        g  filenamef  eliminator.scm
+droppable? C(R89:;<=        h8      ] 45	 45	 45	  C        g  filenamef  eliminator.scm
  
 	 		 			 		 		 	,	 		 		 		 		 	,	" 		# 		' 		) 		. 	,	1 		3 		6 	 		7
-  g  nameg  get-options C>R?  h   H   ]4 5$  	"  ,4 	5$  	"  4 	5$  	"   C         g  options
+  g  nameg  get-options C>R?  hH      ]4 5$  	"  ,4 	5$  	"  4 	5$  	"   C         g  options
 		F  g  filenamef  eliminator.scm
  
 	 		 		 		 		  		% 		, 		5 		: 		D 	 		F  g  nameg  
-apply-options C@R1A9BC    h   @   ]45   $    6 $  
+apply-options C@R1A9BC    h@      ]45   $    6 $  
 45 C
 45 C             g  x
 		:  g  filenamef  eliminator.scm
  
 	 		 		 		 		 	#	 	-	 		" 		$ 	(	( 	*	* 	(	- 	 	0 	(	4 	*	6 	(	9 	  		:
-  g  nameg  get-hint CDR     h      `] C       X    g  filenamef  eliminator.scm
+  g  nameg  get-hint CDR     h   `   ] C    X       g  filenamef  eliminator.scm
  
  		
-  g  nameg  do-deal-next-cards CER   h      U] C       M    g  filenamef  eliminator.scm
+  g  nameg  do-deal-next-cards CER   h   U   ] C    M       g  filenamef  eliminator.scm
  
  		
-  g  nameg  timeout CFR      h      r]C       j    g  slot-id
+  g  nameg  timeout CFR      h   r   ]C    j       g  slot-id
 		  g  filenamef  eliminator.scm
  
  		  g  nameg  button-clicked CGR4HiIi>  "  G  Ji$i'i,iGi0i3i2iDi>i@iFi(i6              g  filenamef  eliminator.scm		
