@@ -1,4 +1,4 @@
-GOOF----BE-4-2.0  (    ] = 4 h      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
+GOOF----LE-8-2.0(      ] = 4 h      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
 g  api	
  	 	
 					 	g  
@@ -23,24 +23,24 @@ move-n-cards!	(g  
 add-to-score!	)g  button-released	*g  button-clicked	+g  
 deal-cards	,g  move-to-foundation	-g  button-double-clicked	.g  game-won	/g  get-hint	0g  game-continuable	1g  to-foundations?	2g  	hint-move	3g  to-tableau?	4g  _	5f  *Move something onto an empty tableau slot.	6g  empties?	7g  get-options	8g  
 apply-options	9g  timeout	:g  set-features	;g  droppable-feature	<g  
-set-lambdaC 5 h  !   ] 4	 >  "  G  
-RR     h    a] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4	>   "  G  4>  "  G  4>   "  G  4>   "  G  4>   "  G  4
+set-lambdaC 5 h!     ] 4	 >  "  G  
+RR     h  a  ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4	>   "  G  4>  "  G  4>   "  G  4>   "  G  4>   "  G  4
 >  "  G  4>   "  G  4>  "  G  4	>   "  G  4>  "  G  4>   "  G  4>   "  G  4>   "  G  4
 >  "  G  4>   "  G  4>  "  G  4	>   "  G  4>  "  G  4>   "  G  4>   "  G  4>   "  G  4
 >  "  G  4>   "  G  4>  "  G  4	>   "  G  4>  "  G  4>   "  G  4>   "  G  4>   "  G  4
 >  "  G  4>   "  G  4>  "  G  4
 	>  "  G  	
-	 C     Y    g  filenamef  fortress.scm
+	 C   Y      g  filenamef  fortress.scm
 	
 							#			3			C			F			J			O			X			h			x		 	 	 	!	 	"	 	"	 	"	 	"	 	$	 	&	 	&	 	&	 	&	 	'	 	(		)		*		*		*	&	+	6	,	9	,	=	,	B	,	K	.	[	0	^	0	b	0	g	0	p	1		2		3		4		4		4		4		5		6		6		6		6		8		:		:		:		:		;	
 	<		=	-	>	0	>	2	>	7	>	@	?	P	@	S	@	W	@	\	@	e	A	u	C	x	C	|	C		C		D		E		F		G		G		G		G		H		I		I		I		I		K		K		K		M	 Z	
-  g  nameg  new-game CR    h   H   ]4 5$  C 	$  C 	$  C 		$  C 	$  C45C          g  slot-id
+  g  nameg  new-game CR    hH      ]4 5$  C 	$  C 	$  C 		$  C 	$  C45C          g  slot-id
 		E g  	card-list		E  g  filenamef  fortress.scm
 	O
 		P		
 	P			Q			P			R		#	P		*	S		.	P		5	T		9	P		<	U	
 	D	U	 		E	  g  nameg  button-pressed C R!
-"#$%     h     ] $  C45$  e45$  45"  $  C45$  C445545$  454455CC45$  C445545$  8445545$  C445545CC          g  
+"#$%     h     ] $  C45$  e45$  45"  $  C45$  C445545$  454455CC45$  C445545$  8445545$  C445545CC          g  
 start-slot
 	  g  	card-list	  g  end-slot		  g  t		5	 g  t	   g  t	    g  filenamef  fortress.scm
 	W
@@ -48,23 +48,23 @@ start-slot
  	b		 	c	 	c	 	c	 	d	 	d	 	d	 	c	 	c	
  	e	 	e	$ 	e	 	f	 	f	) 	f	 	f	 	e	 	e	 	g	 	g	) 	g	 	g	 	h	 	h	$ 	h	 	g	 <	 	  g  nameg  
 droppable? C&R&'!
-(    h   @   ]4 5$  +4 5$  45$  C6CC         g  
+(    h@      ]4 5$  +4 5$  45$  C6CC         g  
 start-slot
 		> g  	card-list		> g  end-slot			> g  t		*	:  g  filenamef  fortress.scm
 	j
-		k			k			l		 	k		!	m		'	m	!	)	m		*	m		*	m		:	n	 		>	  g  nameg  button-released C)R    h      o]C       g    g  slot-id
+		k			k			l		 	k		!	m		'	m	!	)	m		*	m		*	m		:	n	 		>	  g  nameg  button-released C)R    h   o   ]C    g       g  slot-id
 		  g  filenamef  fortress.scm
 	p
- 		  g  nameg  button-clicked C*R$%"+(,# 	 h     ]	$  C"  r45$  "  <445544 55$  445544 55"  $  4  5$  6C 	645$  .44 55$  4  5$  6C"U"Q      g  slot
+ 		  g  nameg  button-clicked C*R$%"+(,# 	 h     ]	$  C"  r45$  "  <445544 55$  445544 55"  $  4  5$  6C 	645$  .44 55$  4  5$  6C"U"Q      g  slot
 	  g  f-slot	   g  filenamef  fortress.scm
 	s
-		t				t			z			z			"	{		%	{		-	{		.	|		1	|		9	|		:	{		>	z			?	}		B	}	!	J	}		K	}		L	~		O	~		W	~		X	}		a	t		b			k			m			q				v 	  	%  	 	t	 	v	 	t	 	w	 	w	 	w	 	w	 	v		 	x	 	x	 	x	 	x		 	y	 +	 	  g  nameg  move-to-foundation C,R,    h   @   ]	4 5$  C 
+		t				t			z			z			"	{		%	{		-	{		.	|		1	|		9	|		:	{		>	z			?	}		B	}	!	J	}		K	}		L	~		O	~		W	~		X	}		a	t		b			k			m			q				v 	  	%  	 	t	 	v	 	t	 	w	 	w	 	w	 	w	 	v		 	x	 	x	 	x	 	x		 	y	 +	 	  g  nameg  move-to-foundation C,R,    h@      ]	4 5$  C 
 $  "   	
 $   	6C              g  slot-id
 		9 g  t		+  g  filenamef  fortress.scm
  
 	 		
- 		 		 		% 		' 		( 		/ 		7 	 		9  g  nameg  button-double-clicked C-R./       h      w] 45 $  C6           o    g  filenamef  fortress.scm
+ 		 		 		% 		' 		( 		/ 		7 	 		9  g  nameg  button-double-clicked C-R./       h   w   ] 45 $  C6        o       g  filenamef  fortress.scm
  
 	 		 		 	 		
   g  nameg  game-continuable C0R        h      ] 4
@@ -74,7 +74,7 @@ start-slot
  
 	 		 		
  		 		 		! 		" 		, 		- 		7 		8 		B 		C 		M 		N 		X 		Y 		c 		i 	 		{
-  g  nameg  game-won C.R1$%"2#    h  (  ]* 	$  C4 5$  "  Y 	$  "  D 	$  "  / 		$  "   	$  "  	$  	 	6"  d45$  "  <445544 55$  44 554455"  $  	 6 	645$   44 55$  	 6"q"m             g  slot
+  g  nameg  game-won C.R1$%"2#    h(    ]* 	$  C4 5$  "  Y 	$  "  D 	$  "  / 		$  "   	$  "  	$  	 	6"  d45$  "  <445544 55$  44 554455"  $  	 6 	645$   44 55$  	 6"q"m             g  slot
 	! g  f-slot	! g  t			} g  t		&	z g  t		8	w g  t		J	t g  t		\	q  g  filenamef  fortress.scm
  
 	 			 		 	
@@ -83,7 +83,7 @@ start-slot
 	8 			J 	
 	J 			\ 	
 	\ 			n 	
-  	  	  		  	  		  	  	  	  	  	  	  	  		  	  	  	  	  	!  	  	  	  	  		  	"  	  	  	  	  	 		 	 	 		 		 1	!	  g  nameg  to-foundations? C1R3$%"2    h  h  3]* 	$  C4 5$  "  Y	$  "  D 	$  "  / 	$  "   		$  "   	$   	 6	$  "  /	$  "  		$  "  	$  "  v45$  "  f44 554455$  H44 554455$  "  445544 55"  $  	 6 6    +    g  slot1
+  	  	  		  	  		  	  	  	  	  	  	  	  		  	  	  	  	  	!  	  	  	  	  		  	"  	  	  	  	  	 		 	 	 		 		 1	!	  g  nameg  to-foundations? C1R3$%"2    hh  3  ]* 	$  C4 5$  "  Y	$  "  D 	$  "  / 	$  "   		$  "   	$   	 6	$  "  /	$  "  		$  "  	$  "  v45$  "  f44 554455$  H44 554455$  "  445544 55"  $  	 6 6  +      g  slot1
 	f g  slot2	f g  t			} g  t		&	z g  t		8	w g  t		J	t g  t		\	q g  t	   g  t	   g  t	   g  t	!K  g  filenamef  fortress.scm
  
 	 			 		 	
@@ -92,15 +92,15 @@ start-slot
 	8 			J 	
 	J 			\ 	
 	\ 			n 	
-  	  	  	"  		  	  	  	  	  	  	  	  		  	  		  	  	  	  	  	 	 	 		 	 	  	 	 	% 	  	! 	! 	/ 	2 	 : 	; 	> 	%F 	G 	H 	T 	] 		d 	f 		 :	f	  g  nameg  to-tableau? C3R45        h     ]H4
+  	  	  	"  		  	  	  	  	  	  	  	  		  	  		  	  	  	  	  	 	 	 		 	 	  	 	 	% 	  	! 	! 	/ 	2 	 : 	; 	> 	%F 	G 	H 	T 	] 		d 	f 		 :	f	  g  nameg  to-tableau? C3R45        h     ]H4
 5  $  "  45$  "  4	5$  "  4	5$  "  z4	5$  "  c4	5$  "  L4	5$  "  54	
 5$  "  4	5$  "  4	
 5 $  
-45 CC      g  t
+45 CC      g  t
 	  g  t	  g  t		/  g  t		C  g  t		W  g  t		k  g  t		  g  t	   g  t	    	g  filenamef  fortress.scm
  
 	 		 		 		 		) 		/ 		= 		C 		Q 		W 		e 		k 		y 		 	  	  	  	  	  	  	  	  	  	  	 	 
-  g  nameg  empties? C6R136  h   0   ]4
+  g  nameg  empties? C6R136  h0      ]4
 	5  $   C4
 5  $   C6             g  t
 	
@@ -109,14 +109,14 @@ start-slot
  
 	 		
  		 		 		+ 	 		+
-  g  nameg  get-hint C/R    h      W] C       O    g  filenamef  fortress.scm
+  g  nameg  get-hint C/R    h   W   ] C    O       g  filenamef  fortress.scm
  
  		
-  g  nameg  get-options C7R    h      o]C       g    g  options
+  g  nameg  get-options C7R    h   o   ]C    g       g  options
 		  g  filenamef  fortress.scm
  
  		  g  nameg  
-apply-options C8R    h      S] C       K    g  filenamef  fortress.scm
+apply-options C8R    h   S   ] C    K       g  filenamef  fortress.scm
  
  		
   g  nameg  timeout C9R4:i;i>  "  G  <ii i)i*i-i0i.i/i7i8i9i&i6             g  filenamef  fortress.scm		
