@@ -1,4 +1,4 @@
-GOOF----LE-8-2.00      ] i 4     h      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
+GOOF----BE-8-2.0  0    ] i 4     h      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
 g  api	
  	 	
 g  ice-9	g  format	
@@ -15,11 +15,11 @@ set-score!	Wg  any-slot-empty?	Xf  
 Deal a row	Yg  	hint-move	Zf   Try moving a card to the reserve	[f  Try dealing a row of cards	\f  Try moving card piles around	]g  begin-exclusive	^f  	Same suit	_f  Alternating colors	`g  
 end-exclusive	ag  get-options	bg  list-ref	cg  
 apply-options	dg  timeout	eg  set-features	fg  droppable-feature	gg  dealable-feature	hg  
-set-lambdaC 5      h&    ] 4	 >  "  G  4i>   "  G  
-RRR	R  h   Y   ] 6   Q       g  filenamef  	giant.scm
+set-lambdaC 5      h  &  ] 4	 >  "  G  4i>   "  G  
+RRR	R  h      Y] 6      Q    g  filenamef  	giant.scm
 	
 			 		
-  g  nameg  	make-deck CR	hRRR !"#$%&'()       h    ] 4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4	>   "  G  4
+  g  nameg  	make-deck CR	hRRR !"#$%&'()       h    ] 4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>   "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4>  "  G  4	>   "  G  4
 >  "  G  4
 >  "  G  4
 >  "  G  4
@@ -29,13 +29,13 @@ set-lambdaC 5      h&    ] 4	 >  "  G  4i>   "  G  
 >  "  G  4
 >  "  G  4>   "  G  4
 >  "  G  4>  "  G  4>   "  G  	
- C         g  filenamef  	giant.scm
+ C         g  filenamef  	giant.scm
 	#
 		$			%		#	&		3	)		9	)		>	)		G	*		W	+		Z	+		\	+		a	+		j	,		m	,		o	,		t	,		}	-	 	-	 	-	 	-	 	.	 	.	 	.	 	.	 	/	 	/	 	/	 	/	 	0	 	0	 	0	 	0	 	1	 	1	 	1	 	1	 	2	 	2	 	2	 	2	 	3	 	4		4		4		4		5		5		5	 	5	)	6	,	6	0	6	5	6	>	7	A	7	E	7	J	7	S	8	V	8	Z	8	_	8	h	9	k	9	o	9	t	9	}	:		:		:		:		;		;		;		;		<		=		=		=		=		?		B		C		C	 S	
-  g  nameg  new-game C*R+,   h   k   ] 45 6     c       g  filenamef  	giant.scm
+  g  nameg  new-game C*R+,   h      k] 45 6        c    g  filenamef  	giant.scm
 	E
 		F			F	 		
-  g  nameg  give-status-message C(R-./01        h(      ] 4544455	56             g  filenamef  	giant.scm
+  g  nameg  give-status-message C(R-./01        h   (   ] 4544455	56             g  filenamef  	giant.scm
 	I
 		K	
 	
@@ -44,11 +44,11 @@ set-lambdaC 5      h&    ] 4	 >  "  G  4i>   "  G  
 	L	
 		L			L	%		L			L		 	L	
 	"	J	 		"
-  g  nameg  get-stock-no-string C,R234      h(      ]45$   456 6       g  
+  g  nameg  get-stock-no-string C,R234      h   (   ]45$   456 6       g  
 start-slot
 		( g  	card-list		( g  end-slot			(  g  filenamef  	giant.scm
 	R
-		S			S			T	)		T		(	U	 		(	  g  nameg  complete-transaction C5R6789   hh      ]
+		S			S			T	)		T		(	U	 		(	  g  nameg  complete-transaction C5R6789   h   h   ]
 4 5$  "   $  C$  "  45$  "  $  45"  $  6C           g  slot
 		d g  	card-list		d g  t				 g  t		6	X  g  filenamef  	giant.scm
 	Y
@@ -56,79 +56,79 @@ start-slot
 			Z			Z		"	Z		*	\		0	\	&	6	\	
 	I	]		J	]	!	\	\		b	^	
  
-		d	  g  nameg  button-pressed C:R2986;<=>74?0   h    ] $  C45$  r45$  b45$  R45$  45"  44544	55$  4544	55"  "  "  "  $  C4
+		d	  g  nameg  button-pressed C:R2986;<=>74?0   h    ] $  C45$  r45$  b45$  R45$  45"  44544	55$  4544	55"  "  "  "  $  C4
 5$  45$  $  "  45$  "  $  45"  $  45$  "  44
 5544	55$  `$  "  44
 5544	55$  "  %$  44
 5544	55"  "  "  "  "  $  C$  45$  
-45CCC          g  
+45CCC          g  
 start-slot
 	 g  	card-list	 g  end-slot		 g  t	  g  t	   g  t	=s g  t	  g  filenamef  	giant.scm
 	b
 		c			c			d			d			e		%	d		&	f		0	d		1	g		;	g		<	h		A	h	$	C	h		F	h		K	i		P	i	(	R	i		S	i	9	V	i	C	^	i	9	_	i		c	i		d	j	!	i	j	,	k	j	!	l	j		m	j	A	p	j	L	x	j	A	y	j	 	d	 	n	 	n	 	o	 	n	 	p	 	p	+ 	p	 	q	 	q	& 	n	 	r	 	r	 	s	! 	s	1	s	,	s	!	s		s	K
 	s	V	s	K	s		s		t	#	u	/&	u	?-	u	9/	u	/0	u	U3	u	^;	u	U<	u	)=	u	$=	t	Q	v	R	w	'U	w	6\	w	1^	w	'_	w	Lb	w	Vj	w	Lk	w	$	d		{		{		|		{		}		}	 R		  g  nameg  
-droppable? C@R@5   h       ]4 5$  
+droppable? C@R@5   h       ]4 5$  
  6C          g  
 start-slot
 		 g  	card-list		 g  end-slot			  g  filenamef  	giant.scm
  
-	 		 		 	 			  g  nameg  button-released CAR'  h   d   ] 6      \       g  filenamef  	giant.scm
+	 		 		 	 			  g  nameg  button-released CAR'  h      d] 6         \    g  filenamef  	giant.scm
  
 	
  	 		
 
-  g  nameg  do-deal-next-cards CBRCB       h       ] $  45 $  6 CC           g  slot
+  g  nameg  do-deal-next-cards CBRCB       h       ] $  45 $  6 CC           g  slot
 		  g  filenamef  	giant.scm
  
 	 		 		 	
-	 		 	 		  g  nameg  button-clicked CDREF    h0      ]	 &  C4 5$  	  C 6          g  
+	 		 	 		  g  nameg  button-clicked CDREF    h   0   ]	 &  C4 5$  	  C 6          g  
 from-slots
 		- g  find-to-result		-  g  filenamef  	giant.scm
  
 	 			 		 		 	0	 		 		 		  		% 		+ 	$	- 	 
-		-  g  nameg  find-any-to-foundation CFR6G       h8   
-  ] &  C$   C4 5$  	 6 4 5C      g  slots
+		-  g  nameg  find-any-to-foundation CFR6G       h   8  
+] &  C$   C4 5$  	 6 4 5C      g  slots
 		8 g  with-empties		8  g  filenamef  	giant.scm
  
 	 			 		
  		 		 		 		 		  		% 	3	) 	%	, 		- 	#	2 	1	6 	#	7 	 		8	  g  nameg  without-gaps CGREGH019>6 
-    h     ] &  C445 5 "  	 6$  u4455$  "  44545 5$  64	5$  "  4455$   C""|"x       g  
+    h     ] &  C445 5 "  	 6$  u4455$  "  44545 5$  64	5$  "  4455$   C""|"x       g  
 from-slots
 	  g  with-empties	  g  find-to-result		  g  cfs		  g  t		D	m g  t		y   g  filenamef  	giant.scm
  
-	 			 		 		 	%	 	I	 		 		 		, 	!	0 		0 		7 		: 	 	B 		D 		D 		R 		U 	@	\ 	Y	c 	S	g 	:	i 		j 		q 		r 		y 		y 	  	  	   	  	  	  	 #	 	  g  nameg  find-any-to-tableau CHRFI      h       ]	4 5$  6C         g  slots
+	 			 		 		 	%	 	I	 		 		 		, 	!	0 		0 		7 		: 	 	B 		D 		D 		R 		U 	@	\ 	Y	c 	S	g 	:	i 		j 		q 		r 		y 		y 	  	  	   	  	  	  	 #	 	  g  nameg  find-any-to-tableau CHRFI      h       ]	4 5$  6C         g  slots
 		 g  find-any-result			  g  filenamef  	giant.scm
  
-	 			 		 		 		 	+	 	 		  g  nameg  move-any-to-foundation CJRJKLM        h       ] 44 55$  6C        g  filenamef  	giant.scm
+	 			 		 		 		 	+	 	 		  g  nameg  move-any-to-foundation CJRJKLM        h       ] 44 55$  6C        g  filenamef  	giant.scm
  
 	 		 	 	 	0	 	 	 		 		 	 			
-  g  nameg  	auto-play CMR6@>E        hH     ]
-45$  "   $  C445  5$   C 6       g  slots
+  g  nameg  	auto-play CMR6@>E        h   H  ]
+45$  "   $  C445  5$   C 6       g  slots
 		H g  	from-slot		H g  t				  g  filenamef  	giant.scm
  
 	 	
-		 		 	-	 	"	! 		$ 		) 	'	2 	!	5 	A	7 		; 		> 		D 		H 	 		H	  g  nameg  find-to CER6NO   h(      ]$  4 5"  $  C4 56        g  	from-slot
+		 		 	-	 	"	! 		$ 		) 	'	2 	!	5 	A	7 		; 		> 		D 		H 	 		H	  g  nameg  find-to CER6NO   h   (   ]$  4 5"  $  C4 56        g  	from-slot
 		' g  to-slot		'  g  filenamef  	giant.scm
  
-	 			 		 		 		 		' 	 		'	  g  nameg  move-a-card CIRIE    h      ] 4 56       }       g  	from-slot
+	 			 		 		 		 		' 	 		'	  g  nameg  move-a-card CIRIE    h      ] 4 56          }    g  	from-slot
 		  g  filenamef  	giant.scm
  
-	 		 	 		  g  nameg  move-to-foundation CPR2MP        h@      ]	4 5$  6 4 5$  "   $   6C          g  slot
+	 		 	 		  g  nameg  move-to-foundation CPR2MP        h   @   ]	4 5$  6 4 5$  "   $   6C          g  slot
 		= g  t		1  g  filenamef  	giant.scm
  
 	 		 		 		 		 		. 	)	5 		; 	 
-		=  g  nameg  button-double-clicked CQR(RS    h(   v   ] 4>   "  G  45 $  C6        n       g  filenamef  	giant.scm
+		=  g  nameg  button-double-clicked CQR(RS    h   (   v] 4>   "  G  45 $  C6           n    g  filenamef  	giant.scm
  
 	 		 		 		! 	 		!
-  g  nameg  	game-over CTR01U     h(      ] (  
+  g  nameg  	game-over CTR01U     h   (   ] (  
 C44 554 5C              g  	slot-list
 		!  g  filenamef  	giant.scm
  
 	 		 			 		 		 		 			 	.	 	:	 	.	  	 		!  g  nameg  
-game-score CURVU    h   u   ] 4455C      m       g  filenamef  	giant.scm
+game-score CURVU    h      u] 4455C         m    g  filenamef  	giant.scm
  
 	 		 		 		 	 		
-  g  nameg  game-won CRR6W-X      h@      ]45$  "    $  "  45 $  
+  g  nameg  game-won CRR6W-X      h   @   ]45$  "    $  "  45 $  
 45 CC         g  t
 		,  g  filenamef  	giant.scm
  
@@ -136,11 +136,11 @@ game-score CURVU    h   u   ] 4455C      m       g  fil
 	
  		 		" 		) 		0 		2 		6 		8 		; 	 		>
   g  nameg  	dealable? CCRFKHY6-ZC[\ 
-    h   6  ]44 5544 5544 55  $    6$  6$  645$  
+    h     6]44 5544 5544 55  $    6$  6$  645$  
 4	5 C4
 5 $  
 45 C
-45 C     .      g  find-result
+45 C       .    g  find-result
 	7  g  	t-result1	7  g  	t-result2		7   g  filenamef  	giant.scm
 
 						-			=			-				
@@ -151,18 +151,18 @@ game-score CURVU    h   u   ] 4455C      m       g  fil
 		&		)	+	2	;	4	+	7		7			C		H		L	+	O		U		Z		^	)	a		g		l		p	)	s		t	
 	~	 	0 	2 	0 	( 	
  	 	! 	# 	! 	 	 	 	 	 .	 
-  g  nameg  get-hint CSR]-^_`       h(      ] 45 45  C            g  filenamef  	giant.scm
+  g  nameg  get-hint CSR]-^_`       h   (   ] 45 45  C            g  filenamef  	giant.scm
 
 																			&					"	 		#
-  g  nameg  get-options CaRb     h      ]4 5 C       g  options
+  g  nameg  get-options CaRb     h      ]4 5 C       g  options
 		  g  filenamef  	giant.scm
 
 	 		 		 	 		  g  nameg  
-apply-options CcR    h   P   ] C    H       g  filenamef  	giant.scm
+apply-options CcR    h      P] C       H    g  filenamef  	giant.scm
 "
  		
   g  nameg  timeout CdR4eifigi>  "  G  hi*i:iAiDiQiTiRiSiaicidi@iCi6
- ~      g  filenamef  	giant.scm		
+   ~    g  filenamef  	giant.scm		
 		
 	1	
 	3			6	
