@@ -1,4 +1,4 @@
-GOOF----BE-8-2.0  5#    ] ^ 4        h  >    ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
+GOOF----LE-4-2.0#5      ] ^ 4        h>      ] g  guile	 	g  process-use-modules	 	 	g  	aisleriot	g  	interface	 		 	
 g  api	
  	 	
 						
@@ -20,8 +20,8 @@ flip-stock	@g  button-clicked	Ag  remove-card	Bg  button-double-clicked	C
 flippable?	Eg  	dealable?	Fg  get-hint	Gg  game-continuable	Hg  game-won	Ig  empty-exist?	Jg  	hint-move	Kg  find-empty-slot	Lg  check-waste-to-empty	Mg  stripped-len	Ng  check-tableau-to-empty	Og  check-empty?	Pg  check-a-foundation	Qg  check-to-foundations	Rg  
 check-a-tslot	Sg  check-tslot	Tg  check-to-tableau	Uf  Deal another round	Vf  Move waste back to stock	Wg  get-options	Xg  
 apply-options	Yg  timeout	Zg  set-features	[g  droppable-feature	\g  dealable-feature	]g  
-set-lambdaC 5     h  +  i] 4	 >  "  G  
-RR ! h    ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>  "  G  4	>   "  G  4
+set-lambdaC 5     h+  i  ] 4	 >  "  G  
+RR ! h    ] 4>   "  G  4>   "  G  4>   "  G  4>   "  G  4>  "  G  4>  "  G  4	>   "  G  4
 >  "  G  4
 >  "  G  4
 >  "  G  4
@@ -33,70 +33,70 @@ set-lambdaC 5     h  +  i] 4	 >  "  G  
 >  "  G  4
 >  "  G  4
 >  "  G  4
->  "  G  4>  "  G  4>   "  G  		 C   {    g  filenamef  thumb-and-pouch.scm
+>  "  G  4>  "  G  4>   "  G  		 C {      g  filenamef  thumb-and-pouch.scm
 	
 							#			3			C			I			N			W			Z			\			a			j	 		z	!		}	!			!	 	!	 	"	 	"	 	"	 	"	 	#	 	#	 	#	 	#	 	$	 	$	 	$	 	$	 	%	 	&	 	&	 	&	 	&	 	'	 	'	 	'	 	'	 	(		(		(		(		)		)		)	!	)	*	*	-	*	1	*	6	*	?	+	B	+	F	+	K	+	T	,	W	,	[	,	`	,	i	.	n	.	s	.	|	0		2		4	 A	
-  g  nameg  new-game C"R#$%&'    h      ] 445 45 56        g  filenamef  thumb-and-pouch.scm
+  g  nameg  new-game C"R#$%&'    h      ] 445 45 56        g  filenamef  thumb-and-pouch.scm
 	6
 		7			7	(		8	(		9	(		7			7	 		
-  g  nameg  give-status-message C!R$()*+,-      h       ] 45444
+  g  nameg  give-status-message C!R$()*+,-      h       ] 45444
 5556        g  filenamef  thumb-and-pouch.scm
 	;
 		<				<			<		
 	<	"		=			=	!		=	)		=	!		=			<	 		
-  g  nameg  get-stock-no-string C%R$(.*+/        h       ] 454	56              g  filenamef  thumb-and-pouch.scm
+  g  nameg  get-stock-no-string C%R$(.*+/        h       ] 454	56              g  filenamef  thumb-and-pouch.scm
 	?
 		@				@			@		
 	@	$		A			A	!		A			@	 
 		
-  g  nameg  get-redeals-string C'R,01       h   @   ]
+  g  nameg  get-redeals-string C'R,01       h@      ]
  $  "   $  
 45"  $  456C         g  slot-id
 		> g  	card-list		> g  t			,  g  filenamef  thumb-and-pouch.scm
 	C
-		D			D			E			E			F		$	F		0	D		3	G		:	G		<	G	 		>	  g  nameg  button-pressed C2R34567       h     ]4 >  "  G  4 5$  4	>  "  G  "   45$  4>  "  G  "   4 5$  "  	4 5$  4 >  "  G  "   C            g  
+		D			D			E			E			F		$	F		0	D		3	G		:	G		<	G	 		>	  g  nameg  button-pressed C2R34567       h     ]4 >  "  G  4 5$  4	>  "  G  "   45$  4>  "  G  "   4 5$  "  	4 5$  4 >  "  G  "   C            g  
 start-slot
 	  g  	card-list	  g  end-slot		   g  filenamef  thumb-and-pouch.scm
 	I
-		J			K		%	K		&	L		<	M		H	M		I	N		^	O		h	O		n	P		z	O		{	Q	 	 	  g  nameg  complete-transaction C8R469:1;,<     h    ] $  C45$  Y45$  "  =44554455&  "  44554455"  $  C45$  s4	5$  d45$  
-45"  $  C45$  C445545&  445545CCCC             g  
+		J			K		%	K		&	L		<	M		H	M		I	N		^	O		h	O		n	P		z	O		{	Q	 	 	  g  nameg  complete-transaction C8R469:1;,<     h    ] $  C45$  Y45$  "  =44554455&  "  44554455"  $  C45$  s4	5$  d45$  
+45"  $  C45$  C445545&  445545CCCC             g  
 start-slot
 	 g  	card-list	 g  end-slot		 g  t		!	o g  t		t g  t	    g  filenamef  thumb-and-pouch.scm
 	T
 		U			U			V			V			W		!	W		0	X	#	3	X	-	;	X	#	<	Y	#	?	Y	2	F	Y	-	H	Y	#	L	X		R	Z		U	Z	'	]	Z		^	[	!	a	[	1	h	[	,	j	[	!	k	[		l	Z		t	V	 	\	 	\	 	]	 	]	 	\	 	^	 	^	 	_	  	_	+ 	_	  	_	 	^	 	`	 	`	 	a	 	a	( 	a	 	b	 	b	( 	b	 	`	 	c	 	c	' 	c	 	d	 	d	* 	d	 	d	 	c	 7		  g  nameg  
-droppable? C=R=8  h       ]4 5$  
+droppable? C=R=8  h       ]4 5$  
  6C          g  
 start-slot
 		 g  	card-list		 g  end-slot			  g  filenamef  thumb-and-pouch.scm
 	f
-		g			g			h	 			  g  nameg  button-released C>R?!      h       ] 
+		g			g			h	 			  g  nameg  button-released C>R?!      h       ] 
 $  4
 	5$  6 CC        g  slot-id
 		  g  filenamef  thumb-and-pouch.scm
 	j
 		k		
 	k			l			k			m	 		  g  nameg  button-clicked C@R46:9;<A8 
-h  X  ])4 5$  "   $ ,4 5$  C4 545454	5$  	"  44	55$  	"  4	5$  	"  44	55$  	"  [4	5$  	"  44	55$  	"  .4	5$  	"  44	55$  	"  $  E$  "  4455$  4 5$  
-	  6CCCC             g  slot-id
+hX    ])4 5$  "   $ ,4 5$  C4 545454	5$  	"  44	55$  	"  4	5$  	"  44	55$  	"  [4	5$  	"  44	55$  	"  .4	5$  	"  44	55$  	"  $  E$  "  4455$  4 5$  
+	  6CCCC             g  slot-id
 	Q g  t		 g  card	7O g  suit		@O g  value		IO g  end-slot	 O g  t	
 -  g  filenamef  thumb-and-pouch.scm
 	o
 		p			p			q		#	p		$	r		.	p		1	s		7	s		:	t		@	s		C	u		I	s		L	w		V	w		[	x		b	y	#	e	y	-	m	y	#	n	y		r	w		y	z	 	z	 	{	 	|	# 	|	- 	|	# 	|	 	w	 	}	 	}	 	~	 		# 		- 		# 		 	w	  	  	  	  	#  	-  	#  	 	w	 	v		 	
  	
- 	 	 	"& 	) 	;* 	1 	2 	< 	E 	.I 	 <	Q  g  nameg  button-double-clicked CBR?!     h       w] 4
-	>  "  G  6          o    g  filenamef  thumb-and-pouch.scm
+ 	 	 	"& 	) 	;* 	1 	2 	< 	E 	.I 	 <	Q  g  nameg  button-double-clicked CBR?!     h    w   ] 4
+	>  "  G  6       o       g  filenamef  thumb-and-pouch.scm
  
 	 		 	 		
-  g  nameg  do-deal-next-cards CCRD        h      e] 
-	6         ]    g  filenamef  thumb-and-pouch.scm
+  g  nameg  do-deal-next-cards CCRD        h   e   ] 
+	6      ]       g  filenamef  thumb-and-pouch.scm
  
 	
  	 		
 
-  g  nameg  	dealable? CERF  h      l] 6      d    g  filenamef  thumb-and-pouch.scm
+  g  nameg  	dealable? CERF  h   l   ] 6   d       g  filenamef  thumb-and-pouch.scm
  
 	 	 		
-  g  nameg  game-continuable CGR,- h   X  ] 	
+  g  nameg  game-continuable CGR,- hX     ] 	
 44	55$  :	
 44	55$  %	
 44	55$  	
@@ -111,31 +111,31 @@ h  X  ])4 5$  "   $ ,4 5$  C4 54545
 	7 		; 		> 	
 	A 		I 	
 	J 	 		Q
-  g  nameg  game-won CHR6I       h   (   ] 	
+  g  nameg  game-won CHR6I       h(      ] 	
 $  C4 5$  C 6              g  slot-id
 		!  g  filenamef  thumb-and-pouch.scm
  
-	 			 		 			 		 		! 		 		!  g  nameg  empty-exist? CIR6JK      h       ] 45$  C456            g  filenamef  thumb-and-pouch.scm
+	 			 		 			 		 		! 		 		!  g  nameg  empty-exist? CIR6JK      h       ] 45$  C456            g  filenamef  thumb-and-pouch.scm
  
 	 		 		 		 	 		
-  g  nameg  check-waste-to-empty CLR0M  h       ]4 5$  
+  g  nameg  check-waste-to-empty CLR0M  h       ]4 5$  
  6C           g  	card-list
 		 g  acc		  g  filenamef  thumb-and-pouch.scm
  
 	 		 		 		 		 		 	$	 	 				  g  nameg  stripped-len CMR601-JMKN 
-       h   X  *] 	
-$  C4 5$  "  444 555$   44 55456	 6     "    g  slot-id
+       hX   *  ] 	
+$  C4 5$  "  444 555$   44 55456	 6   "      g  slot-id
 		U  g  filenamef  thumb-and-pouch.scm
  
-	 			 		 		 			 		! 	%	$ 	.	, 	%	- 	 	/ 		0 		4 		9 		< 	*	E 		F 	A	N 			S 	$	U 	 		U  g  nameg  check-tableau-to-empty CNRINL h   (   ]4	5$  4	5  $   C6 C          g  t
+	 			 		 		 			 		! 	%	$ 	.	, 	%	- 	 	/ 		0 		4 		9 		< 	*	E 		F 	A	N 			S 	$	U 	 		U  g  nameg  check-tableau-to-empty CNRINL h(      ]4	5$  4	5  $   C6 C          g  t
 		#  g  filenamef  thumb-and-pouch.scm
  
 	 		
  		 		 		# 	 		%
-  g  nameg  check-empty? COR69:;JP<       h     ]	$  "   
+  g  nameg  check-empty? COR69:;JP<       h     ]	$  "   
 $  "  4 5$  C"  c45$  "  1445545&  454455"  $   
 $  C 6 645$  %45$   
-$  C 6"m"i           g  slot-id
+$  C 6"m"i           g  slot-id
 	  g  card	  g  f-slot		  g  t			2 g  t			/  g  filenamef  thumb-and-pouch.scm
  
 	 	
@@ -144,22 +144,22 @@ $  C 6"m"i           g  slot-id
   		  	
   	*  		  	  	  	  	  	  		  	
   		  	
- $	 	  g  nameg  check-a-foundation CPRQP:       h   @   ]	 	$  C 	$  	64 4 5	5$  C 6         g  slot-id
+ $	 	  g  nameg  check-a-foundation CPRQP:       h@      ]	 	$  C 	$  	64 4 5	5$  C 6         g  slot-id
 		> g  t	,	>  g  filenamef  thumb-and-pouch.scm
  
 	 			 		 			 		 			 	
 	" 	)	, 	
 	, 			< 	#	> 	
  
-		>  g  nameg  check-to-foundations CQR,0;9PJR     h     ]45
+		>  g  nameg  check-to-foundations CQR,0;9PJR     h     ]45
 $  "  )45$  "  4545$  C4545$  p4545&  "  T45$  "  '45$  "  
-4		5$  4 5"  "  $  C 6           g  	from-slot
+4		5$  4 5"  "  $  C 6           g  	from-slot
 	  g  to-slot	  g  	num-cards		  g  card		  g  	card-list		  g  t			D g  t		!	A g  t	   g  t	   g  t	    
 g  filenamef  thumb-and-pouch.scm
  
 	 		 		 		 		 	"	  		! 		! 		/ 		4 		6 		7 	0	> 		H 		K 		R 		W 	#	Y 		Z 		[ 		_ 		` 		g 		l 	$	n 		r 		x 	  	  	  	  	&  	  	  	  	  	+  	  	  	  	  	,  	A  	 -	 	  g  nameg  
-check-a-tslot CRRS6R:-        h     ]
-	$  C	$   	64 5$  	 6$  .45$  "  4 4 545 5"  $  C4 4 5455$  C 6      g  to-slot
+check-a-tslot CRRS6R:-        h     ]
+	$  C	$   	64 5$  	 6$  .45$  "  4 4 545 5"  $  C4 4 5455$  C 6      g  to-slot
 	  g  	from-slot	  g  t		i  g  t	    g  filenamef  thumb-and-pouch.scm
  
 	 			 		 			 		 			 			) 		0 		2 			6 		: 	
@@ -167,13 +167,13 @@ check-a-tslot CRRS6R:-        h     ]
 	J 		R 	!	Y 	'	b 	!	d 		i 			u 	
 	} 	  	  	
   		  	"  	
- 	 	  g  nameg  check-tslot CSRST       h   (   ]	 	$  C4 5$  C 6        g  slot-id
+ 	 	  g  nameg  check-tslot CSRST       h(      ]	 	$  C4 5$  C 6        g  slot-id
 		' g  t		'  g  filenamef  thumb-and-pouch.scm
  
-	 		 		 		 		% 		' 	 		'  g  nameg  check-to-tableau CTRQTO6(U/V 	   h     R]45  $   C4	5  $   C45   $   C4
+	 		 		 		 		% 		' 	 		'  g  nameg  check-to-tableau CTRQTO6(U/V 	   h   R  ]45  $   C4	5  $   C45   $   C4
 5$  "  
 45   $   C45$  C	$  
-45 CC     J    g  t
+45 CC   J      g  t
 		} g  t
 		} g  t
 	*	} g  t
@@ -183,18 +183,18 @@ check-a-tslot CRRS6R:-        h     ]
 	F		J		L		O		O 		[		d	
 	k		o	
 	q		u		w		z	 		}
-  g  nameg  get-hint CFR h      ^] C       V    g  filenamef  thumb-and-pouch.scm
+  g  nameg  get-hint CFR h   ^   ] C    V       g  filenamef  thumb-and-pouch.scm
 
  		
-  g  nameg  get-options CWR     h      v]C       n    g  options
+  g  nameg  get-options CWR     h   v   ]C    n       g  options
 		  g  filenamef  thumb-and-pouch.scm
 	
  		  g  nameg  
-apply-options CXR     h      Z] C       R    g  filenamef  thumb-and-pouch.scm
+apply-options CXR     h   Z   ] C    R       g  filenamef  thumb-and-pouch.scm
 
  		
   g  nameg  timeout CYR4Zi[i\i>  "  G  ]i"i2i>i@iBiGiHiFiWiXiYi=iEi6
-         a    g  filenamef  thumb-and-pouch.scm		
+       a      g  filenamef  thumb-and-pouch.scm		
 					
 	 			#	
 	
